// mozileCommands.js

/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *		Karl Guertin <grayrest@grayrest.com>
 *		James A. Overton <james@overton.ca>
 *		Christian Stocker (Bitflux)
 *		Paul Everitt
 *		David Palm
 *
 * ***** END LICENSE BLOCK ***** */

/*******

Mozile Commands Javascript
Mozile version 0.6.13

Created by James A. Overton
Created on 2004-03-24

Last revised by James A. Overton
Last revised on 2004-06-20

Last revised by Richard Prescott
Last revised on 2004-04-18
Added some namespace support

HISTORY:
	Some code in this file was first found in mozilehtmltb.js, while the 
majority was cut out of mozileTB.js and separated into different files.


DESCRIPTION:
	This file handles the mozileFormat and mozileCommand functions,
which do the work when buttons are pressed or menuitems selected.

*********/


var mozileDialogMode ="";

function mozileGetMode() {
	return mozileDialogMode;
}



// Mozile Show Hide Tags
// creates a link to a special stylesheet, or removes it

function mozileShowHideTags() {
	var f = ["mozileCommands.js","mozileShowHideTags"];
	mozileDebug(f,2,"Showing or Hiding tags");
	
	var head = mozileTarget.document.getElementsByTagName("head")[0];
	var id = "mozile-show-tags";
	var link = mozileTarget.document.getElementById(id);
	var button = document.getElementById("mozile-view-tags");
	
	var tagCSS = mozileTarget.document.MOZILE_RSD_CONFIG["tagCSS"];

	if(tagCSS=="XHTML" || !tagCSS || tagCSS=="") {
		var href = "chrome://mozile/content/mes/tags-XHTML.css";
	} else {
		var href = tagCSS;
	}
	
	if(!head) {
		var head = mozileTarget.document.documentElement;
	}

	//mozileDebug(f,2,"Node: "+document.documentElement);
	if(link) {
		head.removeChild(link);
		button.setAttribute("active","false");
		return;
	}
	
	link = document.createElementNS("http://www.w3.org/1999/xhtml","link");
	link.id = id;
	link.setAttribute("rel","stylesheet");
	link.setAttribute("type","text/css");
	link.setAttribute("href",href);
	head.appendChild(link);
	button.setAttribute("active","true");
	
}











/********* Button/MenuItem Handling Functions *********/


// Mozile Format
// This is called by formatting commands of all sorts.
// It looks the command key up in a big array, which is stored in mozileTBCOmmands.js
// Then it follows the instructions in the array, collaing various eDOM functions

function mozileFormat(key) {
	var f = ["mozileCommands.js","mozileFormat"];
	mozileDebug(f,2,"Format command: "+key);
	
		// make sure Mozile is detected
	if(!mozileDetect()) {
		mozileDebug(f,0,"No selection for Mozile to edit!");
		return;
	}

		// if there is no entry in the array, throw an error
	var commandIndex = findByName(key, mesCommands)
	if(commandIndex<0) {
		alert('Command  "'+ key +'" not defined!');
	}
	var command = mesCommands[commandIndex];
	var name = command[0];
	var title = command[1];
	var tooltip = command[2];
	var icon = command[3];
	var type = command[6];
	var args = command[7];

		// the main switch
	switch(type)
	{
		case "toggleStyle":
			mozileDo(name);
			mozileSelection.toggleTextStyle(args[0], args[1], args[2]);
			break;
			
		case "toggleAttribute":
			mozileDo(name);
			mozileSelection.toggleAttribute(args[0], args[1], args[2]);
			break;

		case "styleText":
			mozileDo(name);
			mozileSelection.styleText(args[0], args[1]);
			break;
			
		case "styleLines":
			mozileDo(name);
			mozileSelection.styleLines(args[0], args[1]);
			break;

		case "setLinesContainer":
			mozileDo(name);
			mozileSelection.changeLinesContainerNS(args[0], args[1]);
			break;

		case "wrapText":
			mozileDo(name);
			try
			{
				var cssr = mozileSelection.getEditableRange();
				if(!cssr)
					break;
				cssr.wrapTextNS(args[0], args[1]);
				mozileSelection.selectEditableRange(cssr);
			}
			catch(e)
			{
				alert("Wrap: "+e);
			}
			break;

		case "toggleListLines":
			mozileDo(name);
			mozileSelection.toggleListLines(args[0], args[1]);
			break;
			
		case "indent":
			dump("this");
			mozileDo(name);
			mozileSelection.indentLines();
			break;

		case "outdent":
			mozileDo(name);
			mozileSelection.outdentLines();
			break;

		case 'link':
			if(mozileSelection.isCollapsed) // must have a selection or don't prompt
				return;
					var href = prompt("Enter a URL:", "");
			if(href == null) // null href means prompt canceled - BUG FIX FROM Karl Guertin
				return;
			if(href != "") {
				mozileDo(name);
				mozileSelection.linkText(href);
			}
			else {
				mozileDo(name);
				mozileSelection.clearTextLinks();
			}
			break;

		case "unlink":
			mozileDo(name);
			mozileSelection.clearTextLinks();
			break;

		case "unformat":
			mozileDo(name);
			mozileSelection.removeLinesContainer();
			break;

		case 'table':
			var rowno = prompt("number of rows");
			var colno = prompt("number of columns");
			var te = mozileTarget.documentCreateXHTMLTable(rowno, colno);
			if(!te)
				alert("Can't create table: invalid data");
			else
				mozileDo(name);
				mozileSelection.insertNode(te);
			break;

		case 'image': // need to replace with native file selection dialog
					var imgref = prompt("Enter the image url or file name:", "");
			if(imgref == null) // null href means prompt canceled
				return;
			if(imgref == "")
				return; // ok with no name filled in
			var img = mozileTarget.documentCreateXHTMLElement("img");
			img.src = imgref; // any way to tell if it is valid?
			mozileDo(name);
			mozileSelection.insertNode(img);
			break;

		case 'hr':
			var hr = mozileTarget.documentCreateXHTMLElement("hr");
			mozileDo(name);
			mozileSelection.insertNode(hr);
			break;
					

			// if the command type hasn't been found, throw an error
		default:
			alert('Command type "'+ command[2] +'" not defined!');
		break;
	}

} // end mozileFormat()


// Mozile Command
// This function is used for non-formatting commands
// All of the behaviours are in here, or called from here.

function mozileCommand(name) {
	var f = ["mozileCommands.js","mozileCommand"];
	mozileDebug(f,2,"Command: "+name);

		// These commands don't require an editable selection
	switch(name) {
		case "options":
			window.open("chrome://mozile/content/XUL/options.xul", "options", "modal,centerscreen,chrome,resizable=no");
			return;
			break;
		case "home":
			window.open('http://mozile.mozdev.org');
			return;
			break;
		case "about":
			window.open("chrome://mozile/content/XUL/about.xul", "about", "modal,centerscreen,chrome,resizable=no");
			return;
			break;
		case "help":
			window.open('chrome://mozile/content/docs/mozileDocs.xml');
			return;
			break;
		case "bug":
			window.open("chrome://mozile/content/XUL/debugging.xul", "debugging", "centerscreen,chrome,resizable=yes");
			return;
			break;
	}
	
		// The following commands do require an editable selection,
		// so make sure Mozile is detected
	if(!mozileDetect()) {
		mozileDebug(f,0,"You have to be editing with Mozile before this command can take effect!");
		return;
	}

	try {
		// run over the switch, some of these are iffy, so they're in try blocks
		switch(name) {
			case 'undo':
					mozileUndo();
				break;
			case 'redo':
				mozileRedo();
				break;
			case 'copy':
				mozileCopy();
				break;
			case 'cut':
				mozileCut();
				break;
			case 'paste':
				mozilePaste();
				break;
			
				// Saving is handled by mozileTBSave.js
			case "save":
				window.open("chrome://mozile/content/XUL/save.xul", "options", "modal,centerscreen,chrome,resizable=no");
				break;
				
			case "view-tags":
				mozileShowHideTags();
				break;
			
			case "info":
				window.open("chrome://mozile/content/XUL/info.xul", "rsd", "modal,centerscreen,chrome,resizable=no");
				break;
		}
	} catch(e) {
		mozileDebug(f,0,"Command error: "+ name +" -->"+e); 
	}
}	// end mozileCommand()


